@@ -12,7 +12,7 @@ import prov.model as pm
 from prov.model import QualifiedName
 from prov.model import Namespace as provNamespace
 import requests
-from fuzzywuzzy import fuzz
+from rapidfuzz import fuzz
 import json
 from github import Github, GithubException
 import getpass
@@ -1224,7 +1224,8 @@ def find_concept_interactive(source_variable, current_tuple, source_variable_ann
             go_loop = False
         else:
             # user selected one of the existing concepts to add its URL to the isAbout property
-            source_variable_annotations[current_tuple]['isAbout'] = search_result[search_result[selection]]['preferred_url']
+            # added labels to these isAbout urls for easy querying later
+            source_variable_annotations[current_tuple]['isAbout'] = {search_result[search_result[selection]]['preferred_url'] : search_result[search_result[selection]]['label']}
             print("\nConcept annotation added for source variable: %s" %source_variable)
             go_loop = False
 
@@ -1461,7 +1462,21 @@ def DD_to_nidm(dd_struct):
             elif key == 'isAbout':
                 #dct_ns = Namespace(Constants.DCT)
                 #g.bind(prefix='dct', namespace=dct_ns)
-                g.add((cde_id, Constants.NIDM['isAbout'], URIRef(value)))
+                # added by DBK for multiple isAbout URLs and storing the labels along with URLs
+                # first get a uuid has for the isAbout collection for this we'll use a hash of the isAbout list
+                # as a string
+                crc32hash = base_repr(crc32(str(value).encode()), 32).lower()
+                # now create the collection and for each isAbout create an entity to add to collection with
+                # properties for label and url
+                #g.add((isabout_collection_id, RDF.type, Constants.PROV['Collection']))
+                # for each isAbout entry, create new prov:Entity, store metadata and link it to the collection
+                for isabout_key, isabout_value in value.items():
+                    # add isAbout key which is the url
+                    g.add((cde_id, Constants.NIDM['isAbout'], URIRef(isabout_key)))
+                    # now add another entity to contain the label
+                    g.add((URIRef(isabout_key), RDF.type,Constants.PROV['Entity']))
+                    g.add((URIRef(isabout_key), Constants.RDFS['label'], Literal(isabout_value)))
+
             elif key == 'valueType':
                 g.add((cde_id, Constants.NIDM['valueType'], URIRef(value)))
             elif key == 'minimumValue':
