@@ -4,7 +4,7 @@ import os.path
 # Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
 _version_major = 3
 _version_minor = 5 
-_version_micro = '2'  # use '' for first of series, number for 1 and above
+_version_micro = '5'  # use '' for first of series, number for 1 and above
 _version_extra = ''
 # _version_extra = ''  # Uncomment this for full releases
 
@@ -55,7 +55,7 @@ MAJOR = _version_major
 MINOR = _version_minor
 MICRO = _version_micro
 VERSION = __version__
-INSTALL_REQUIRES = ["prov", "graphviz", "pydotplus", "pydot", "validators", "requests", "fuzzywuzzy", "pygithub",
-                    "pandas", "pybids", "duecredit", "pytest", "graphviz", "click", "neurdflib-jsonld",
-                    "pyld", "neurdflib", "datalad", "ontquery>=0.2.2", "orthauth>=0.0.8","tabulate", "joblib", "cognitiveatlas", "numpy", "etelemetry"]
+INSTALL_REQUIRES = ["prov", "graphviz", "pydotplus", "pydot", "validators", "requests", "rapidfuzz", "pygithub",
+                    "pandas", "pybids", "duecredit", "pytest", "graphviz", "click", "rdflib-jsonld",
+                    "pyld", "rdflib", "datalad", "ontquery>=0.2.2", "orthauth>=0.0.8","tabulate", "joblib", "cognitiveatlas", "numpy", "etelemetry","click-option-group"]
 SCRIPTS = ["bin/nidm_query", "bin/bidsmri2nidm", "bin/csv2nidm","bin/nidm_utils"]
